@@ -1086,3 +1086,37 @@
 #define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_86
 #define GOBJECT_AVAILABLE_TYPE_IN_2_86
 #endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_88
+#define GOBJECT_DEPRECATED_IN_2_88 GOBJECT_DEPRECATED
+#define GOBJECT_DEPRECATED_IN_2_88_FOR(f) GOBJECT_DEPRECATED_FOR (f)
+#define GOBJECT_DEPRECATED_MACRO_IN_2_88 GLIB_DEPRECATED_MACRO
+#define GOBJECT_DEPRECATED_MACRO_IN_2_88_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_88 GLIB_DEPRECATED_ENUMERATOR
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_88_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GOBJECT_DEPRECATED_TYPE_IN_2_88 GLIB_DEPRECATED_TYPE
+#define GOBJECT_DEPRECATED_TYPE_IN_2_88_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GOBJECT_DEPRECATED_IN_2_88 _GOBJECT_EXTERN
+#define GOBJECT_DEPRECATED_IN_2_88_FOR(f) _GOBJECT_EXTERN
+#define GOBJECT_DEPRECATED_MACRO_IN_2_88
+#define GOBJECT_DEPRECATED_MACRO_IN_2_88_FOR(f)
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_88
+#define GOBJECT_DEPRECATED_ENUMERATOR_IN_2_88_FOR(f)
+#define GOBJECT_DEPRECATED_TYPE_IN_2_88
+#define GOBJECT_DEPRECATED_TYPE_IN_2_88_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_88
+#define GOBJECT_AVAILABLE_IN_2_88 GOBJECT_UNAVAILABLE (2, 88)
+#define GOBJECT_AVAILABLE_STATIC_INLINE_IN_2_88 GLIB_UNAVAILABLE_STATIC_INLINE (2, 88)
+#define GOBJECT_AVAILABLE_MACRO_IN_2_88 GLIB_UNAVAILABLE_MACRO (2, 88)
+#define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_88 GLIB_UNAVAILABLE_ENUMERATOR (2, 88)
+#define GOBJECT_AVAILABLE_TYPE_IN_2_88 GLIB_UNAVAILABLE_TYPE (2, 88)
+#else
+#define GOBJECT_AVAILABLE_IN_2_88 _GOBJECT_EXTERN
+#define GOBJECT_AVAILABLE_STATIC_INLINE_IN_2_88
+#define GOBJECT_AVAILABLE_MACRO_IN_2_88
+#define GOBJECT_AVAILABLE_ENUMERATOR_IN_2_88
+#define GOBJECT_AVAILABLE_TYPE_IN_2_88
+#endif
